@@ -15,6 +15,20 @@ ggplot(vaccinations,
   theme(legend.position = "none") +
   ggtitle("vaccination survey responses", "labeled using `geom_text()`")
 
+## ----omit----------------------------------------------------------------
+ggplot(vaccinations,
+       aes(x = survey, stratum = response, alluvium = subject, y = freq,
+           fill = response, label = response)) +
+  scale_x_discrete(expand = c(.1, 0)) +
+  geom_flow(width = 1/4) +
+  geom_stratum(alpha = .5, width = 1/4) +
+  geom_text(stat = "stratum", size = 4, min.height = 100) +
+  theme(legend.position = "none") +
+  ggtitle(
+    "vaccination survey responses",
+    "labeled using `geom_text()` with `min.height = 100`"
+  )
+
 ## ----aesthetics----------------------------------------------------------
 print(ggrepel::GeomTextRepel$required_aes)
 print(ggfittext:::GeomFitText$required_aes)
