@@ -1,16 +1,15 @@
 # full axis width
 ggplot(as.data.frame(Titanic),
-       aes(weight = Freq,
+       aes(y = Freq,
            axis1 = Class, axis2 = Sex, axis3 = Age, axis4 = Survived)) +
   geom_stratum(width = 1) + geom_text(stat = "stratum", label.strata = TRUE) +
-  scale_x_continuous(breaks = 1:4,
-                     labels = c("Class", "Sex", "Age", "Survived"))
+  scale_x_discrete(limits = c("Class", "Sex", "Age", "Survived"))
   
 # use of facets
 ggplot(as.data.frame(Titanic),
-       aes(weight = Freq,
+       aes(y = Freq,
            axis1 = Class, axis2 = Sex)) +
   geom_flow(aes(fill = Survived)) +
   geom_stratum() + geom_text(stat = "stratum", label.strata = TRUE) +
-  scale_x_continuous(breaks = 1:2, labels = c("Class", "Sex")) +
+  scale_x_discrete(limits = c("Class", "Sex")) +
   facet_wrap(~ Age, scales = "free_y")
